==> jexpress-2.3.7-sources.jar: org/summerboot/jexpress/nio/server/domain/ErrorCodeSerializer.java <==
/*
 * Copyright 2005-2022 Du Law Office - The Summer Boot Framework Project
 *
 * The Summer Boot Project licenses this file to you under the Apache License, version 2.0 (the
 * "License"); you may not use this file except in compliance with the License and you have no
 * policy prohibiting employee contributions back to this file (unless the contributor to this
 * file is your current or retired employee). You may obtain a copy of the License at:
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.summerboot.jexpress.nio.server.domain;

import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.io.IOException;
import org.summerboot.jexpress.boot.SummerApplication;

/**
 *
 * @author Changski Tie Zheng Zhang 张铁铮, 魏泽北, 杜旺财, 杜富贵
 */
public class ErrorCodeSerializer extends JsonSerializer<String> {

    @Override
    public void serialize(String value, JsonGenerator jg, SerializerProvider sp) throws IOException {
        if (SummerApplication.SystemErrorCodeAsInt) {
            int intValue = Integer.parseInt(value);
            jg.writeNumber(intValue);
        } else {
            jg.writeString(value);
        }
    }

}

==> jexpress-2.3.12-sources.jar: org/summerboot/jexpress/nio/server/domain/ErrorCodeSerializer.java <==
/*
 * Copyright 2005-2022 Du Law Office - The Summer Boot Framework Project
 *
 * The Summer Boot Project licenses this file to you under the Apache License, version 2.0 (the
 * "License"); you may not use this file except in compliance with the License and you have no
 * policy prohibiting employee contributions back to this file (unless the contributor to this
 * file is your current or retired employee). You may obtain a copy of the License at:
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.summerboot.jexpress.nio.server.domain;

import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.io.IOException;
import org.summerboot.jexpress.boot.BootConstant;

/**
 *
 * @author Changski Tie Zheng Zhang 张铁铮, 魏泽北, 杜旺财, 杜富贵
 */
public class ErrorCodeSerializer extends JsonSerializer<String> {

    @Override
    public void serialize(String value, JsonGenerator jg, SerializerProvider sp) throws IOException {
        if (BootConstant.CFG_ERROR_CODE_AS_INT) {
            int intValue = Integer.parseInt(value);
            jg.writeNumber(intValue);
        } else {
            jg.writeString(value);
        }
    }

}
